from distutils.core import setup
setup(
  name = 'rapiflash',
  packages = ['rapiflash'],
  version = '0.4',
  description = 'A Python wrapper for Rapiflash (Real-time Alerts of Potential Increases to Flood Level for Avoiding Significant Harm) which allows developers to gather river water levels from around the world',
  author = 'Devin Mui',
  author_email = 'devinmui@yahoo.com',
  url = 'https://github.com/devinmui/rapiflash-api',
  download_url = 'https://github.com/devinmui/rapiflash-python/tarball/0.2',
  keywords = ['floods']
)
